RegularLayer

Struct RegularLayer 

pub struct RegularLayer<F: Field> {
    id: LayerId,
    pub(crate) expression: Expression<F, ProverExpr>,
    sumcheck_rounds: Vec<usize>,
    beta_vals_vec: Option<Vec<BetaValues<F>>>,
}
The most common implementation of crate::layer::Layer.

A regular layer is made up of a structured polynomial relationship between MLEs of previous layers.

Proofs are generated with the Sumcheck protocol.

Fields

id: LayerId

This layer’s ID.

expression: Expression<F, ProverExpr>

The polynomial expression defining this layer. It includes information on how this layer relates to the others.

sumcheck_rounds: Vec<usize>

Stores the indices of the sumcheck rounds in this GKR layer so we only produce sumcheck proofs over those. When we use interpolative claim aggregation, this is all of the nonlinear variables in the expression. When we use RLC claim aggregation, this is all of the variables in the expression.

beta_vals_vec: Option<Vec<BetaValues<F>>>

Stores the beta values associated with the expression. Initially set to None. Computed during initialization.

Implementations

Source

impl<F: Field> RegularLayer<F>

pub fn new_raw(id: LayerId, expression: Expression<F, ProverExpr>) -> Self

Creates a new RegularLayer from an Expression and a LayerId

The Expression is the relationship this Layer proves and the LayerId is the location of this Layer in the overall circuit

pub fn get_expression(&self) -> &Expression<F, ProverExpr>

Returns a reference to the expression that this layer is proving.

pub fn append_leaf_mles_to_transcript( &self, transcript_writer: &mut impl ProverTranscript<F>, ) -> Result<()>

Traverse the fully-bound self.expression and append all MLE values to the trascript.